@@ -35,7 +35,10 @@ import org.apache.http.HttpException;
  * Abstract server-side HTTP protocol handler.
  *
  * @since 4.0
+ *
+ * @deprecated (4.2) use {@link NHttpServerEventHandler}
  */
+@Deprecated
 public interface NHttpServiceHandler {
 
     /**
