@@ -27,7 +27,7 @@
 package org.apache.http.nio.pool;
 
 import java.io.IOException;
-import java.net.SocketTimeoutException;
+import java.net.ConnectException;
 import java.util.concurrent.ExecutionException;
 
 import org.apache.http.concurrent.BasicFuture;
@@ -171,7 +171,7 @@ public class TestRouteSpecificPool {
             future.get();
             Assert.fail("ExecutionException should have been thrown");
         } catch (final ExecutionException ex) {
-            Assert.assertTrue(ex.getCause() instanceof SocketTimeoutException);
+            Assert.assertTrue(ex.getCause() instanceof ConnectException);
         }
         Assert.assertEquals(0, pool.getAllocatedCount());
         Assert.assertEquals(0, pool.getAvailableCount());
